@@ -59,7 +59,7 @@ def model_switch(model):
     LOGGER.info("Switch model to deploy modality.")  
     
     
-class Yolov6Detector:
+class YOLOV6:
     def __init__(
         self, 
         weights = 'weights/yolov6s.pt',
@@ -220,11 +220,12 @@ class Yolov6Detector:
 
     
 if __name__ == '__main__':
-    model = Yolov6Detector(
+    model = YOLOV6(
         weights='weights/yolov6s.pt',
         device='cuda:0',
         half=False
     )
+
     model = model.predict(
         source='data/images/',
         yaml='data/coco.yaml',
